@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '2.004004'; # VERSION
+our $VERSION = '2.006000'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -77,6 +77,7 @@ around add_file => sub {
 	foreach my $holder ( split( /\s/xms, join( ' ',
 			@{ $self->zilla->authors },
 			$self->zilla->copyright_holder,
+			@{ $self->zilla->distmeta->{x_contributors} || [] },
 		))
 	) {
 		$self->add_stopword( $holder );
@@ -131,7 +132,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.004004
+version 2.006000
 
 =head1 SYNOPSIS
 
@@ -189,7 +190,8 @@ C<stopwords> can appear multiple times, one word per line.
 Normally no stopwords are added by default, but author names appearing in
 C<dist.ini> are automatically added as stopwords so you don't have to add them
 manually just because they might appear in the C<AUTHORS> section of the
-generated POD document.
+generated POD document. The same goes for contributors listed under the
+'x_contributors' field on your distributions META file.
 
 =head1 METHODS
 
